@@ -11,6 +11,7 @@
 #include "clonedialog.h"
 #include "commitdialog.h"
 #include "gitwrapper.h"
+#include "progressdialog.h"
 #include "pulldialog.h"
 #include "pushdialog.h"
 #include "tagdialog.h"
@@ -264,6 +265,12 @@ bool FileViewGitPlugin::beginRetrieval(const QString &directory)
             }
         }
     }
+
+    const auto untracked = GitWrapper::instance()->listUntracked();
+    for (auto &i : std::as_const(untracked)) {
+        m_versionInfoHash.insert(directory + i, UnversionedVersion);
+    }
+
     return true;
 }
 
@@ -276,8 +283,11 @@ KVersionControlPlugin::ItemVersion FileViewGitPlugin::itemVersion(const KFileIte
     const QString itemUrl = item.localPath();
     if (m_versionInfoHash.contains(itemUrl)) {
         return m_versionInfoHash.value(itemUrl);
+    } else if (m_versionInfoHash.contains(m_currentDir + QStringLiteral("."))) {
+        // We are inside unversioned directory - everything is unversioned.
+        return UnversionedVersion;
     } else {
-        // files that are not in our map are normal, tracked files by definition
+        // files that are not in our map are normal, tracked files by definition.
         return NormalVersion;
     }
 }
@@ -302,8 +312,8 @@ QList<QAction *> FileViewGitPlugin::versionControlActions(const KFileItemList &i
 
 QList<QAction *> FileViewGitPlugin::outOfVersionControlActions(const KFileItemList &items) const
 {
-    // Only for a single directory.
-    if (items.count() != 1 || !items.first().isDir()) {
+    // Only for a single local writable directory.
+    if (items.count() != 1 || !items.first().isDir() || !items.first().isWritable() || !items.first().isLocalFile()) {
         return {};
     }
 
@@ -557,79 +567,40 @@ void FileViewGitPlugin::clone()
 {
     CloneDialog dialog(m_contextDir, m_parentWidget);
     if (dialog.exec() == QDialog::Accepted) {
-        QStringList arguments = {dialog.url(), dialog.directory(), QStringLiteral("clone"), QStringLiteral("--progress")};
+        QStringList arguments = {
+            QStringLiteral("clone"),
+            QStringLiteral("--progress"),
+            dialog.url(),
+            dialog.directory(),
+        };
         if (dialog.recursive()) {
             arguments << QStringLiteral("--recurse-submodules");
         }
-        if (dialog.bare()) {
-            arguments << QStringLiteral("--bare");
-        }
-        if (dialog.noCheckout()) {
-            arguments << QStringLiteral("--no-checkout");
-        }
-        const auto depth = dialog.depth();
-        if (depth > 0) {
-            arguments << QStringLiteral("--depth") << QString::number(depth);
-        }
         const QString branch = dialog.branch();
         if (!branch.isEmpty()) {
             arguments << QStringLiteral("--branch") << branch;
         }
 
         QProcess *process = new QProcess(m_parentWidget);
-        QDialog *progressDialog = new QDialog(m_parentWidget);
-        QVBoxLayout *layout = new QVBoxLayout;
-        QPlainTextEdit *text = new QPlainTextEdit;
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-        layout->addWidget(text);
-        layout->addWidget(buttonBox);
-        progressDialog->setLayout(layout);
-        connect(buttonBox, &QDialogButtonBox::rejected, process, &QProcess::terminate);
-        connect(buttonBox, &QDialogButtonBox::accepted, progressDialog, &QDialog::accept);
+        QDialog *progressDialog = new ProgressDialog(process, m_parentWidget);
+
         connect(process, &QProcess::errorOccurred, this, [this, process](QProcess::ProcessError) {
-            const QString commandLine = process->program() + process->arguments().join(QLatin1Char(' '));
+            const QString commandLine = process->program() + QLatin1Char(' ') + process->arguments().join(QLatin1Char(' '));
             Q_EMIT errorMessage(xi18nd("@info:status", "<application>Git</application> error starting: %1", commandLine));
         });
-        connect(process, &QProcess::finished, process, [this, process, buttonBox](int exitCode, QProcess::ExitStatus) {
+        connect(process, &QProcess::finished, process, [this, process](int exitCode, QProcess::ExitStatus) {
             if (exitCode != EXIT_SUCCESS) {
                 Q_EMIT errorMessage(xi18nd("@info:status", "<application>Git</application> clone failed: %1", process->errorString()));
             } else {
                 Q_EMIT operationCompletedMessage(xi18nd("@info:status", "<application>Git</application> clone complete."));
             }
-
-            buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
-            buttonBox->button(QDialogButtonBox::Cancel)->setEnabled(false);
         });
-        // git clone outputs only to stderr but we connect stdout anyway.
-        connect(process, &QProcess::readyReadStandardOutput, text, [text, process]() {
-            auto input = process->readAllStandardOutput();
-            auto list = QString::fromLocal8Bit(input).split(QLatin1Char('\r'), Qt::SkipEmptyParts);
-            text->moveCursor(QTextCursor::End);
-            for (auto &i : std::as_const(list)) {
-                text->moveCursor(QTextCursor::StartOfBlock, QTextCursor::KeepAnchor);
-                text->textCursor().removeSelectedText();
-                text->insertPlainText(i);
-            }
-        });
-        connect(process, &QProcess::readyReadStandardError, text, [text, process]() {
-            auto input = process->readAllStandardError();
-            auto list = QString::fromLocal8Bit(input).split(QLatin1Char('\r'), Qt::SkipEmptyParts);
-            text->moveCursor(QTextCursor::End);
-            for (auto &i : std::as_const(list)) {
-                text->moveCursor(QTextCursor::StartOfBlock, QTextCursor::KeepAnchor);
-                text->textCursor().removeSelectedText();
-                text->insertPlainText(i);
-            }
-        });
-        buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
         progressDialog->setWindowTitle(dialog.windowTitle());
-        progressDialog->setAttribute(Qt::WA_DeleteOnClose);
-        progressDialog->resize(progressDialog->sizeHint() + QSize{200, 0});
         progressDialog->show();
 
         process->setWorkingDirectory(m_contextDir);
         process->start(QStringLiteral("git"), arguments);
-        Q_EMIT infoMessage(xi18nd("@info:status", "<application>Git</application> clone repository..."));
+        Q_EMIT infoMessage(xi18nd("@info:status", "<application>Git</application> cloning repository..."));
     }
 }
 
